@@ -12,6 +12,7 @@ from spei.resources import Orden, Respuesta
 from spei.utils import format_data
 
 logger = logging.getLogger('spei')
+logger.setLevel(logging.DEBUG)
 
 
 class BaseClient(object):
@@ -57,7 +58,8 @@ class BaseClient(object):
         checksum = self.generate_checksum(orden_data)
         orden = orden_cls(op_firma_dig=checksum, **orden_data)
         soap_request = OrdenRequest(orden)
+        logger.info(soap_request)
         response = self.session.post(data=soap_request, url=self.host)
         logger.info(response.text)
         response.raise_for_status()
-        return respuesta_cls.parse_xml(response.text)
+        return respuesta_cls.fromstring(response.text)
