@@ -6,19 +6,22 @@ from spei.utils import to_snake_case, to_upper_camel_case  # noqa: WPS347
 
 
 class Respuesta(BaseModel):
-    categoria: types.CategoriaOrdenPago
-
     id: str
     fecha_oper: int
     err_codigo: types.CodigoError
     err_descripcion: str
+    categoria: types.CategoriaOrdenPago
 
     class Config:  # noqa: WPS306, WPS431
         use_enum_values = True
 
     def build_xml(self):
         qname = etree.QName('http://www.w3.org/2001/XMLSchema-instance', 'type')
-        mensaje = etree.Element('mensaje', {qname: 'mensaje'}, categoria=self.categoria)  # noqa: E501
+        mensaje = etree.Element(
+            'mensaje',
+            {qname: 'mensaje'},
+            categoria=self.categoria,
+        )
         respuesta = etree.SubElement(mensaje, 'respuesta')
 
         for element, value in self.dict(exclude={'categoria'}).items():  # noqa: WPS110
@@ -30,11 +33,11 @@ class Respuesta(BaseModel):
         return mensaje
 
     @classmethod
-    def parse_xml(cls, respuesta_xml, category):
-        respuesta = respuesta_xml.find('respuesta')
+    def parse_xml(cls, mensaje):
+        respuesta = mensaje.find('respuesta')
 
         respuesta_data = {
-            'categoria': category,
+            'categoria': mensaje.attrib['categoria'],
         }
 
         for sub_element in respuesta.getchildren():
